==> jc-1.4.0.tar.gz: javax/swing/JTextField__24AccessibleJTextField.h <==
// public class javax.swing.JTextField$AccessibleJTextField

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 73be17e96ed15ae2 javax_swing_JTextField__24AccessibleJTextField
// @dep_class c8d812b116a1948e javax_swing_text_JTextComponent__24AccessibleJTextComponent

// header file dependencies
// @dep_header javax_swing_text_JTextComponent__24AccessibleJTextComponent

#include "javax/swing/text/JTextComponent__24AccessibleJTextComponent.h"

#ifndef _JC_javax_swing_JTextField__24AccessibleJTextField_H_
#define _JC_javax_swing_JTextField__24AccessibleJTextField_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_swing_JTextField$object;

// Typedefs
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs	_jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs;
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs	_jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs;
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$refs	_jc_javax_swing_JTextField__24AccessibleJTextField$refs;
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$nonrefs	_jc_javax_swing_JTextField__24AccessibleJTextField$nonrefs;
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$object	_jc_javax_swing_JTextField__24AccessibleJTextField$object;

typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$fields_struct	_jc_javax_swing_JTextField__24AccessibleJTextField$fields_struct;
typedef const struct _jc_javax_swing_JTextField__24AccessibleJTextField$vmethods	_jc_javax_swing_JTextField__24AccessibleJTextField$vmethods;
typedef const struct _jc_javax_swing_JTextField__24AccessibleJTextField$vtable	_jc_javax_swing_JTextField__24AccessibleJTextField$vtable;
typedef const struct _jc_javax_swing_JTextField__24AccessibleJTextField$vtype	_jc_javax_swing_JTextField__24AccessibleJTextField$vtype;

// Class fields structure
struct _jc_javax_swing_JTextField__24AccessibleJTextField$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JTextField__24AccessibleJTextField$fields_struct _jc_javax_swing_JTextField__24AccessibleJTextField$class_fields;

// Constructors
extern void _jc_javax_swing_JTextField__24AccessibleJTextField$method$_init$b70b675134a0ef82(_jc_env *, struct _jc_javax_swing_JTextField__24AccessibleJTextField$object *, struct _jc_javax_swing_JTextField$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_javax_swing_JTextField__24AccessibleJTextField$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_javax_swing_JTextField__24AccessibleJTextField$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JTextField__24AccessibleJTextField$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_javax_swing_JTextField__24AccessibleJTextField$vmethods {
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_javax_swing_JTextField__24AccessibleJTextField$object *);
};

// Vtable
struct _jc_javax_swing_JTextField__24AccessibleJTextField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$vmethods	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
	_jc_javax_swing_JTextField__24AccessibleJTextField$vmethods	javax_swing_JTextField__24AccessibleJTextField;
};

// Vtype
struct _jc_javax_swing_JTextField__24AccessibleJTextField$vtype {
	_jc_type			type;
	_jc_javax_swing_JTextField__24AccessibleJTextField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs {
	struct _jc_javax_swing_JTextField$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JTextField__24AccessibleJTextField$refs {
    _jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs	javax_swing_JTextField__24AccessibleJTextField;
    _jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$sub_refs	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JTextField__24AccessibleJTextField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$sub_nonrefs	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
    _jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs	javax_swing_JTextField__24AccessibleJTextField;
};

// Object instance structure
struct _jc_javax_swing_JTextField__24AccessibleJTextField$object {
	_jc_javax_swing_JTextField__24AccessibleJTextField$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JTextField__24AccessibleJTextField$vtype	*vtype;
	_jc_javax_swing_JTextField__24AccessibleJTextField$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JTextField__24AccessibleJTextField$vtype _jc_javax_swing_JTextField__24AccessibleJTextField$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JTextField__24AccessibleJTextField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JTextField__24AccessibleJTextField$class_object;

#endif	/* _JC_javax_swing_JTextField__24AccessibleJTextField_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JTextField__24AccessibleJTextField.h <==
// public class javax.swing.JTextField$AccessibleJTextField

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 73be17e96ed15ae2 javax_swing_JTextField__24AccessibleJTextField
// @dep_class c8d812b116a1948e javax_swing_text_JTextComponent__24AccessibleJTextComponent

// header file dependencies
// @dep_header javax_swing_text_JTextComponent__24AccessibleJTextComponent

#include "javax/swing/text/JTextComponent__24AccessibleJTextComponent.h"

#ifndef _JC_javax_swing_JTextField__24AccessibleJTextField_H_
#define _JC_javax_swing_JTextField__24AccessibleJTextField_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_swing_JTextField$object;

// Typedefs
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs	_jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs;
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs	_jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs;
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$refs	_jc_javax_swing_JTextField__24AccessibleJTextField$refs;
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$nonrefs	_jc_javax_swing_JTextField__24AccessibleJTextField$nonrefs;
typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$object	_jc_javax_swing_JTextField__24AccessibleJTextField$object;

typedef struct _jc_javax_swing_JTextField__24AccessibleJTextField$fields_struct	_jc_javax_swing_JTextField__24AccessibleJTextField$fields_struct;
typedef const struct _jc_javax_swing_JTextField__24AccessibleJTextField$vmethods	_jc_javax_swing_JTextField__24AccessibleJTextField$vmethods;
typedef const struct _jc_javax_swing_JTextField__24AccessibleJTextField$vtable	_jc_javax_swing_JTextField__24AccessibleJTextField$vtable;
typedef const struct _jc_javax_swing_JTextField__24AccessibleJTextField$vtype	_jc_javax_swing_JTextField__24AccessibleJTextField$vtype;

// Class fields structure
struct _jc_javax_swing_JTextField__24AccessibleJTextField$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JTextField__24AccessibleJTextField$fields_struct _jc_javax_swing_JTextField__24AccessibleJTextField$class_fields;

// Constructors
extern void _jc_javax_swing_JTextField__24AccessibleJTextField$method$_init$b70b675134a0ef82(_jc_env *, struct _jc_javax_swing_JTextField__24AccessibleJTextField$object *, struct _jc_javax_swing_JTextField$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_javax_swing_JTextField__24AccessibleJTextField$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_javax_swing_JTextField__24AccessibleJTextField$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JTextField__24AccessibleJTextField$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_javax_swing_JTextField__24AccessibleJTextField$vmethods {
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_javax_swing_JTextField__24AccessibleJTextField$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JTextField__24AccessibleJTextField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$vmethods	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
	_jc_javax_swing_JTextField__24AccessibleJTextField$vmethods	javax_swing_JTextField__24AccessibleJTextField;
};

// Vtype
struct _jc_javax_swing_JTextField__24AccessibleJTextField$vtype {
	_jc_type			type;
	_jc_javax_swing_JTextField__24AccessibleJTextField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs {
	struct _jc_javax_swing_JTextField$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JTextField__24AccessibleJTextField$refs {
    _jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs	javax_swing_JTextField__24AccessibleJTextField;
    _jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$sub_refs	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JTextField__24AccessibleJTextField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$sub_nonrefs	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
    _jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs	javax_swing_JTextField__24AccessibleJTextField;
};

// Object instance structure
struct _jc_javax_swing_JTextField__24AccessibleJTextField$object {
	_jc_javax_swing_JTextField__24AccessibleJTextField$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JTextField__24AccessibleJTextField$vtype	*vtype;
	_jc_javax_swing_JTextField__24AccessibleJTextField$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JTextField__24AccessibleJTextField$vtype _jc_javax_swing_JTextField__24AccessibleJTextField$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JTextField__24AccessibleJTextField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JTextField__24AccessibleJTextField$class_object;

#endif	/* _JC_javax_swing_JTextField__24AccessibleJTextField_H_ */
